@@ -11,9 +11,9 @@ use Perinci::Object;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-28'; # DATE
+our $DATE = '2023-12-08'; # DATE
 our $DIST = 'App-DownloadsDirUtils'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our %SPEC;
 
@@ -96,6 +96,14 @@ MARKDOWN
                 schema => 'dirname*',
                 default => '.',
             },
+            overwrite => {
+                schema => 'true*',
+                cmdline_aliases => {O=>{}},
+            },
+            as => {
+                summary => 'Rename file',
+                schema => 'pathname::unix::basename*',
+            },
         },
         modify_meta => sub {
             my $meta = shift;
@@ -118,12 +126,15 @@ MARKDOWN
             my $i = 0;
             for my $file (@{ $res->[2] }) {
                 $i++;
-                if ($args{-dry_run}) {
-                    log_info "DRY-RUN: [%d/%d] Moving %s to %s ...", $i, scalar(@{ $res->[2] }), $file, $to_dir;
+                my $targetpath = $to_dir . '/' . ($args{as} // $file);
+                if (-e $targetpath && !$args{overwrite}) {
+                    $envres->add_result(409, "File already exist '$targetpath', please choose another name or specify -O to overwrite", {item_id=>$file});
+                } elsif ($args{-dry_run}) {
+                    log_info "DRY-RUN: [%d/%d] Moving %s to %s ...", $i, scalar(@{ $res->[2] }), $file, $targetpath;
                     $envres->add_result(200, "OK (dry-run)", {item_id=>$file});
                 } else {
-                    log_info "[%d/%d] Moving %s to %s ...", $i, scalar(@{ $res->[2] }), $file, $to_dir;
-                    my $ok = File::Copy::Recursive::rmove($file, $to_dir);
+                    log_info "[%d/%d] Moving %s to %s ...", $i, scalar(@{ $res->[2] }), $file, $targetpath;
+                    my $ok = File::Copy::Recursive::rmove($file, $targetpath);
                     if ($ok) {
                         $envres->add_result(200, "OK", {item_id=>$file});
                     } else {
@@ -153,7 +164,7 @@ App::DownloadsDirUtils - Utilities related to downloads directories
 
 =head1 VERSION
 
-This document describes version 0.005 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-11-28.
+This document describes version 0.006 of App::DownloadsDirUtils (from Perl distribution App-DownloadsDirUtils), released on 2023-12-08.
 
 =head1 DESCRIPTION
 
@@ -472,6 +483,10 @@ Arguments ('*' denotes required arguments):
 
 Do not ignore entries starting with .
 
+=item * B<as> => I<pathname::unix::basename>
+
+Rename file.
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -507,6 +522,10 @@ will be returned because are they both rank #1.
 
 Number of results to return.
 
+=item * B<overwrite> => I<true>
+
+(No description)
+
 =item * B<recursive> => I<true>
 
 Recurse into subdirectories.
@@ -570,6 +589,10 @@ Arguments ('*' denotes required arguments):
 
 Do not ignore entries starting with .
 
+=item * B<as> => I<pathname::unix::basename>
+
+Rename file.
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -605,6 +628,10 @@ will be returned because are they both rank #1.
 
 Number of results to return.
 
+=item * B<overwrite> => I<true>
+
+(No description)
+
 =item * B<recursive> => I<true>
 
 Recurse into subdirectories.
@@ -668,6 +695,10 @@ Arguments ('*' denotes required arguments):
 
 Do not ignore entries starting with .
 
+=item * B<as> => I<pathname::unix::basename>
+
+Rename file.
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -699,6 +730,10 @@ will be returned because are they both rank #1.
 
 Number of results to return.
 
+=item * B<overwrite> => I<true>
+
+(No description)
+
 =item * B<recursive> => I<true>
 
 Recurse into subdirectories.
@@ -762,6 +797,10 @@ Arguments ('*' denotes required arguments):
 
 Do not ignore entries starting with .
 
+=item * B<as> => I<pathname::unix::basename>
+
+Rename file.
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -793,6 +832,10 @@ will be returned because are they both rank #1.
 
 Number of results to return.
 
+=item * B<overwrite> => I<true>
+
+(No description)
+
 =item * B<recursive> => I<true>
 
 Recurse into subdirectories.
@@ -856,6 +899,10 @@ Arguments ('*' denotes required arguments):
 
 Do not ignore entries starting with .
 
+=item * B<as> => I<pathname::unix::basename>
+
+Rename file.
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -887,6 +934,10 @@ will be returned because are they both rank #1.
 
 Number of results to return.
 
+=item * B<overwrite> => I<true>
+
+(No description)
+
 =item * B<recursive> => I<true>
 
 Recurse into subdirectories.
@@ -950,6 +1001,10 @@ Arguments ('*' denotes required arguments):
 
 Do not ignore entries starting with .
 
+=item * B<as> => I<pathname::unix::basename>
+
+Rename file.
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -981,6 +1036,10 @@ will be returned because are they both rank #1.
 
 Number of results to return.
 
+=item * B<overwrite> => I<true>
+
+(No description)
+
 =item * B<recursive> => I<true>
 
 Recurse into subdirectories.
